@@ -17,7 +17,7 @@ typedef struct {
 static PyTypeObject EMatrixType;
 
 #define EVSPACE_MODULE
-#include <evspacemodule.h>
+#include "evspacemodule.h"
 
 #define PI 3.14159265358979323846
 
@@ -562,10 +562,22 @@ static PyObject* EVector_Normalize(EVector* self, PyObject* UNUSED)
 	Py_RETURN_NONE;
 }
 
+static PyObject* EVector_Copy(EVector* self, PyObject* UNUSED)
+{
+	EVector* rtn = (EVector*)self->ob_base.ob_type->tp_new(self->ob_base.ob_type, NULL, NULL);
+
+	rtn->m_arr[0] = self->m_arr[0];
+	rtn->m_arr[1] = self->m_arr[1];
+	rtn->m_arr[2] = self->m_arr[2];
+
+	return (PyObject*)rtn;
+}
+
 static PyMethodDef EVector_Methods[] = {
 	{"mag", (PyCFunction)EVector_Mag, METH_NOARGS, "Returns the magnitude of an EVector."},
 	{"mag2", (PyCFunction)EVector_Mag2, METH_NOARGS, "Returns the square of the magnitude of an EVector."},
-	{"normalize", (PyCFunction)EVector_Normalize, METH_NOARGS, "Normalized an EVector."},
+	{"normalize", (PyCFunction)EVector_Normalize, METH_NOARGS, "Normalizes an EVector."},
+	{"copy", (PyCFunction)EVector_Copy, METH_NOARGS, "Returns a deep copy of an EVector."},
 	{NULL}
 };
 
@@ -1015,10 +1027,23 @@ static PyObject* EMatrix_get(EMatrix* self, PyObject* args)
 	return PyFloat_FromDouble(self->m_arr[i][j]);
 }
 
+static PyObject* EMatrix_copy(EMatrix* self, PyObject* UNUSED)
+{
+	EMatrix* rtn = (EMatrix*)self->ob_base.ob_type->tp_new(self->ob_base.ob_type, NULL, NULL);
+
+	for (int i = 0; i < 3; i++) {
+		for (int j = 0; j < 3; j++)
+			rtn->m_arr[i][j] = self->m_arr[i][j];
+	}
+
+	return (PyObject*)rtn;
+}
+
 // todo: can we manage these with a sequence like protocol?
 static PyMethodDef EMatrix_Methods[] = {
 	{"set", (PyCFunction)EMatrix_set, METH_VARARGS, "Sets a matrix comonent to a given value."},
 	{"get", (PyCFunction)EMatrix_get, METH_VARARGS, "Returns a matrix comonent."},
+	{"copy", (PyCFunction)EMatrix_copy, METH_NOARGS, "Returns a deep copy of an EMatrix."},
 	{NULL}
 };
 
